==> zio-aws-ec2_2.13-5.17.125.1-sources.jar: zio/aws/ec2/model/TransitGatewayVpcAttachmentOptions.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class TransitGatewayVpcAttachmentOptions(
    dnsSupport: Option[zio.aws.ec2.model.DnsSupportValue] = None,
    ipv6Support: Option[zio.aws.ec2.model.Ipv6SupportValue] = None,
    applianceModeSupport: Option[zio.aws.ec2.model.ApplianceModeSupportValue] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.TransitGatewayVpcAttachmentOptions = {
    import TransitGatewayVpcAttachmentOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.TransitGatewayVpcAttachmentOptions
      .builder()
      .optionallyWith(dnsSupport.map(value => value.unwrap))(_.dnsSupport)
      .optionallyWith(ipv6Support.map(value => value.unwrap))(_.ipv6Support)
      .optionallyWith(applianceModeSupport.map(value => value.unwrap))(
        _.applianceModeSupport
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.TransitGatewayVpcAttachmentOptions.ReadOnly =
    zio.aws.ec2.model.TransitGatewayVpcAttachmentOptions.wrap(buildAwsValue())
}
object TransitGatewayVpcAttachmentOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.TransitGatewayVpcAttachmentOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.TransitGatewayVpcAttachmentOptions =
      zio.aws.ec2.model.TransitGatewayVpcAttachmentOptions(
        dnsSupport.map(value => value),
        ipv6Support.map(value => value),
        applianceModeSupport.map(value => value)
      )
    def dnsSupport: Option[zio.aws.ec2.model.DnsSupportValue]
    def ipv6Support: Option[zio.aws.ec2.model.Ipv6SupportValue]
    def applianceModeSupport
        : Option[zio.aws.ec2.model.ApplianceModeSupportValue]
    def getDnsSupport: ZIO[Any, AwsError, zio.aws.ec2.model.DnsSupportValue] =
      AwsError.unwrapOptionField("dnsSupport", dnsSupport)
    def getIpv6Support: ZIO[Any, AwsError, zio.aws.ec2.model.Ipv6SupportValue] =
      AwsError.unwrapOptionField("ipv6Support", ipv6Support)
    def getApplianceModeSupport
        : ZIO[Any, AwsError, zio.aws.ec2.model.ApplianceModeSupportValue] =
      AwsError.unwrapOptionField("applianceModeSupport", applianceModeSupport)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.TransitGatewayVpcAttachmentOptions
  ) extends zio.aws.ec2.model.TransitGatewayVpcAttachmentOptions.ReadOnly {
    override val dnsSupport: Option[zio.aws.ec2.model.DnsSupportValue] = scala
      .Option(impl.dnsSupport())
      .map(value => zio.aws.ec2.model.DnsSupportValue.wrap(value))
    override val ipv6Support: Option[zio.aws.ec2.model.Ipv6SupportValue] = scala
      .Option(impl.ipv6Support())
      .map(value => zio.aws.ec2.model.Ipv6SupportValue.wrap(value))
    override val applianceModeSupport
        : Option[zio.aws.ec2.model.ApplianceModeSupportValue] = scala
      .Option(impl.applianceModeSupport())
      .map(value => zio.aws.ec2.model.ApplianceModeSupportValue.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.TransitGatewayVpcAttachmentOptions
  ): zio.aws.ec2.model.TransitGatewayVpcAttachmentOptions.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.195.3-sources.jar: zio/aws/ec2/model/TransitGatewayVpcAttachmentOptions.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class TransitGatewayVpcAttachmentOptions(
    dnsSupport: Optional[zio.aws.ec2.model.DnsSupportValue] = Optional.Absent,
    ipv6Support: Optional[zio.aws.ec2.model.Ipv6SupportValue] = Optional.Absent,
    applianceModeSupport: Optional[
      zio.aws.ec2.model.ApplianceModeSupportValue
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.TransitGatewayVpcAttachmentOptions = {
    import TransitGatewayVpcAttachmentOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.TransitGatewayVpcAttachmentOptions
      .builder()
      .optionallyWith(dnsSupport.map(value => value.unwrap))(_.dnsSupport)
      .optionallyWith(ipv6Support.map(value => value.unwrap))(_.ipv6Support)
      .optionallyWith(applianceModeSupport.map(value => value.unwrap))(
        _.applianceModeSupport
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.TransitGatewayVpcAttachmentOptions.ReadOnly =
    zio.aws.ec2.model.TransitGatewayVpcAttachmentOptions.wrap(buildAwsValue())
}
object TransitGatewayVpcAttachmentOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.TransitGatewayVpcAttachmentOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.TransitGatewayVpcAttachmentOptions =
      zio.aws.ec2.model.TransitGatewayVpcAttachmentOptions(
        dnsSupport.map(value => value),
        ipv6Support.map(value => value),
        applianceModeSupport.map(value => value)
      )
    def dnsSupport: Optional[zio.aws.ec2.model.DnsSupportValue]
    def ipv6Support: Optional[zio.aws.ec2.model.Ipv6SupportValue]
    def applianceModeSupport
        : Optional[zio.aws.ec2.model.ApplianceModeSupportValue]
    def getDnsSupport: ZIO[Any, AwsError, zio.aws.ec2.model.DnsSupportValue] =
      AwsError.unwrapOptionField("dnsSupport", dnsSupport)
    def getIpv6Support: ZIO[Any, AwsError, zio.aws.ec2.model.Ipv6SupportValue] =
      AwsError.unwrapOptionField("ipv6Support", ipv6Support)
    def getApplianceModeSupport
        : ZIO[Any, AwsError, zio.aws.ec2.model.ApplianceModeSupportValue] =
      AwsError.unwrapOptionField("applianceModeSupport", applianceModeSupport)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.TransitGatewayVpcAttachmentOptions
  ) extends zio.aws.ec2.model.TransitGatewayVpcAttachmentOptions.ReadOnly {
    override val dnsSupport: Optional[zio.aws.ec2.model.DnsSupportValue] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dnsSupport())
        .map(value => zio.aws.ec2.model.DnsSupportValue.wrap(value))
    override val ipv6Support: Optional[zio.aws.ec2.model.Ipv6SupportValue] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ipv6Support())
        .map(value => zio.aws.ec2.model.Ipv6SupportValue.wrap(value))
    override val applianceModeSupport
        : Optional[zio.aws.ec2.model.ApplianceModeSupportValue] =
      zio.aws.core.internal
        .optionalFromNullable(impl.applianceModeSupport())
        .map(value => zio.aws.ec2.model.ApplianceModeSupportValue.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.TransitGatewayVpcAttachmentOptions
  ): zio.aws.ec2.model.TransitGatewayVpcAttachmentOptions.ReadOnly =
    new Wrapper(impl)
}
